StripeUserModel class abstract

Data model for storing stripe user data.

Both the payer (customer) and the revenue receiver (account) are stored in this data.

ストライプのユーザーデータを保管するためのデータモデル。

支払う側(カスタマー)や収益を受け取る側(アカウント)両方がこのデータに保存されます。

Available extensions
Annotations
  • @freezed
  • @immutable
  • @CollectionModelPath.new(StripeUserModel.path)

Constructors

StripeUserModel({@JsonKey.new(name: "user") required String userId, @JsonKey.new(name: "account") String? accountId, @JsonKey.new(name: "customer") String? customerId, @JsonKey.new(name: "defaultPayment") String? defaultPayment, @JsonKey.new(name: "capability") @Default.new({}) DynamicMap capablity})
Data model for storing stripe user data.
const
factory
StripeUserModel.fromJson(Map<String, Object?> json)
Convert from JSON.
factory

Properties

accountId String?
no setterinherited
capablity → DynamicMap
no setterinherited
copyWith → $StripeUserModelCopyWith<StripeUserModel>
Create a copy of StripeUserModel with the given fields replaced by the non-null parameter values.
no setterinherited
customerId String?
no setterinherited
defaultPayment String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
registered bool
Returns true if the account is already registered.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_StripeUserModel value)) → TResult

Available on StripeUserModel, provided by the StripeUserModelPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_StripeUserModel value)?) → TResult?

Available on StripeUserModel, provided by the StripeUserModelPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_StripeUserModel value)?, {required TResult orElse()}) → TResult

Available on StripeUserModel, provided by the StripeUserModelPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String userId, String? accountId, String? customerId, String? defaultPayment, DynamicMap capablity)?, {required TResult orElse()}) → TResult

Available on StripeUserModel, provided by the StripeUserModelPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this StripeUserModel to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String userId, String? accountId, String? customerId, String? defaultPayment, DynamicMap capablity)) → TResult

Available on StripeUserModel, provided by the StripeUserModelPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String userId, String? accountId, String? customerId, String? defaultPayment, DynamicMap capablity)?) → TResult?

Available on StripeUserModel, provided by the StripeUserModelPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

collection → const _$$_StripeUserModelCollectionQuery
Query for collection.
document → const _$$_StripeUserModelDocumentQuery
Query for document.
path → const String
Model path.